@@ -22,8 +22,15 @@ sub _learn_from_dom {
 
   $self->SUPER::_learn_from_dom($dom);
 
-  # Mojopaste hack
-  $tmp = $dom->at('body > pre');
+  # Bitbucket hack
+  $tmp = $dom->at('div.codehilite');
+  if ($tmp) {
+    $self->{paste} = $tmp->all_text;
+    $self->template->[1] = 'paste.html.ep';
+  }
+
+  # Mojopaste and Perlbot hack
+  $tmp = $dom->at('body > pre') || $dom->at('pre#paste') || $dom->at('pre.paste');
   if ($tmp and !@{$tmp->children}) {
     $self->{paste} = $tmp->text;
     $self->template->[1] = 'paste.html.ep';
